@@ -846,14 +846,32 @@ class GeckoDriver():
         """
         result_run : bool = False
         message_run : str = ''
+        try:
+            is_admin : bool = True if os.getuid() == 0 else False
+        except:
+            is_admin : bool = False
+            
+        update_command : str = self.setting["FirefoxBrowser"]["FirefoxBrowserUpdater"]
         
         try:
 
             message = f'Trying to update firefox browser to the latest version.'
             logging.info(message)
 
-            os.system(self.setting["FirefoxBrowser"]["FirefoxBrowserUpdater"])
-            time.sleep(60) #wait for the updating - too long
+            if platform.system() == 'Linux':
+
+                if is_admin:
+                    os.system(update_command)
+
+                elif not is_admin:
+                    message = 'You have not ran library with sudo privileges to update firefox browser - so updating is impossible.'
+                    logging.error(message)
+                    return True, message_run
+            
+            else:
+
+                os.system(update_command)
+                time.sleep(60) #wait for the updating - too long
             
             message = f'Firefox browser was successfully updated to the latest version.'
             logging.info(message)
